<?php

namespace Drupal\onlyone;

/**
 * Interface OnlyOneInterface.
 */
interface OnlyOneInterface {

  /**
   * Initial format for nodes description when is used in a drush command.
   */
  const FORMAT_INITIAL_DRUSH = ' (';

  /**
   * Final format for nodes description when is used in a drush command.
   */
  const FORMAT_FINAL_DRUSH = ')';

  /**
   * Initial format for nodes description when is used in the admin interface.
   */
  const FORMAT_INITIAL_ADMIN = ' <strong>(';

  /**
   * Final format for nodes description when is used in the admin interface.
   */
  const FORMAT_FINAL_ADMIN = ') </strong>';

  /**
   * Returns a content type label list.
   *
   * @return array
   *   An associative array with the content type machine name as key
   *   and his label as value.
   */
  public function getContentTypesList();

  /**
   * Returns the temporary table name created with all the content types names.
   *
   * @return string
   *   The temporary table name.
   */
  public function getTemporaryContentTypesTableName();

  /**
   * Returns if exists nodes of a content type in the actual language.
   *
   * @param string $content_type
   *   Content type machine name.
   * @param string $language
   *   The language to check. If the variable is not provided and the site is
   *   multilingual the actual language will be taken.
   *
   * @return int
   *   If exists nodes return the first node nid otherwise return 0.
   */
  public function existsNodesContentType($content_type, $language = NULL);

  /**
   * Delete the content type config variable.
   *
   * @param string $content_type
   *   Content type machine name.
   *
   * @return bool
   *   Return TRUE if the content type config was deleted or FALSE if not
   *   exists.
   */
  public function deleteContentTypeConfig($content_type);

  /**
   * Returns the language label.
   *
   * @param string $language
   *   The language code.
   *
   * @return string
   *   The language label.
   */
  public function getLanguageLabel($language);

}
