<?php

namespace Drupal\onlyone\Plugin\Validation\Constraint;

use Symfony\Component\Validator\Constraint;

/**
 * Checks that Only One node of locked languages exists.
 *
 * If a content type is configured to have Only One node in the locked languages
 * you must follow the same rule, but as the site is never displayed for a
 * locked language the better place to raise an error is with a constraint that
 * will be triggered always when you're trying to add new nodes.
 *
 * @Constraint(
 *   id = "LockedLanguages",
 *   label = @Translation("Locked Languages Constraint", context = "Validation"),
 *   type = "entity:node"
 * )
 */
class LockedLanguagesConstraint extends Constraint {

  /**
   * Message shown when a node of a locked language exists on a content type.
   *
   * The message that will be shown when a node of a locked languages exists on
   * a configured content type and you try to add another for the same language.
   * See https://www.drupal.org/project/onlyone/issues/2962186 for more info.
   *
   * @var string
   */
  public $nodeExists = "The content type %content_type is configured to have Only One node per language but the node <a href=':href'>@title</a> exists for the %language language.";

}
